@@ -8,8 +8,6 @@ from flask_babel import Babel
 from flask_login import current_user
 from flaskext.markdown import Markdown
 
-from scout.utils.matchmaker import mme_nodes
-
 from . import extensions
 from .blueprints import (
     alignviewers,
@@ -57,10 +55,6 @@ def create_app(config_file=None, config=None):
     if config_file:
         app.config.from_pyfile(config_file)
 
-    # If there is a MatchMaker Exchange server
-    # collect the connected external nodes
-    app.mme_nodes = mme_nodes(app.config.get("MME_URL"), app.config.get("MME_TOKEN"))
-
     app.config["JSON_SORT_KEYS"] = False
     current_log_level = LOG.getEffectiveLevel()
     coloredlogs.install(level="DEBUG" if app.debug else current_log_level)
@@ -116,6 +110,10 @@ def configure_extensions(app):
         LOG.info("Gens enabled")
         extensions.gens.init_app(app)
 
+    if all([app.config.get("MME_URL"), app.config.get("MME_ACCEPTS"), app.config.get("MME_TOKEN")]):
+        LOG.info("MatchMaker Exchange enabled")
+        extensions.matchmaker.init_app(app)
+
     if app.config.get("LDAP_HOST"):
         LOG.info("LDAP login enabled")
         # setup connection to server
