@@ -19,7 +19,6 @@ from scout.constants import (
     MOSAICISM_OPTIONS,
     VERBS_MAP,
 )
-from scout.parse.variant.ids import parse_document_id
 from scout.server.extensions import cloud_tracks, gens
 from scout.server.links import ensembl, get_variant_links
 from scout.server.utils import (
@@ -306,30 +305,38 @@ def observations(store, loqusdb, case_obj, variant_obj):
         obs_data(dict)
     """
     chrom = variant_obj["chromosome"]
+    end_chrom = variant_obj.get("end_chrom", chrom)
     pos = variant_obj["position"]
+    end = variant_obj["end"]
     ref = variant_obj["reference"]
     alt = variant_obj["alternative"]
     var_case_id = variant_obj["case_id"]
     var_type = variant_obj.get("variant_type", "clinical")
+    category = variant_obj["category"]
+    if category == "cancer":
+        category = "snv"
+    if category == "cancer_sv":
+        category = "sv"
 
     composite_id = "{0}_{1}_{2}_{3}".format(chrom, pos, ref, alt)
     variant_query = {
         "_id": composite_id,
         "chrom": chrom,
-        "end_chrom": variant_obj.get("end_chrom", chrom),
+        "end_chrom": end_chrom,
         "pos": pos,
-        "end": variant_obj["end"],
+        "end": end,
         "length": variant_obj.get("length", 0),
         "variant_type": variant_obj.get("sub_category", "").upper(),
-        "category": variant_obj["category"],
+        "category": category,
     }
 
     institute_id = variant_obj["institute"]
     institute_obj = store.institute(institute_id)
-    obs_data = loqusdb.get_variant(variant_query, loqusdb_id=institute_obj.get("loqusdb_id")) or {}
+    loqusdb_id = institute_obj.get("loqusdb_id") or "default"
+    obs_data = loqusdb.get_variant(variant_query, loqusdb_id=loqusdb_id)
+
     if not obs_data:
-        LOG.debug("Could not find any observations for %s", composite_id)
-        obs_data["total"] = loqusdb.case_count()
+        obs_data["total"] = loqusdb.case_count(variant_category=category, loqusdb_id=loqusdb_id)
         return obs_data
 
     user_institutes_ids = set([inst["_id"] for inst in user_institutes(store, current_user)])
@@ -352,11 +359,15 @@ def observations(store, loqusdb, case_obj, variant_obj):
         if user_institutes_ids.isdisjoint(other_institutes):
             # If the user does not have access to the information we skip it
             continue
-        document_id = parse_document_id(chrom, str(pos), ref, alt, var_type, case_id)
-        other_variant = store.variant(document_id=document_id)
-        # If the other variant is not loaded we skip it
-        if not other_variant:
-            continue
+
+        other_variant = store.variant(
+            case_id=other_case["_id"], document_id=variant_obj["variant_id"]
+        )
+
+        # IF variant is SV variant, look for variants with different sub_category occurring at the same coordinates
+        if other_variant is None and category == "sv":
+            other_variant = store.overlapping_sv_variant(other_case["_id"], variant_obj)
+
         obs_data["cases"].append(dict(case=other_case, variant=other_variant))
 
     return obs_data
