@@ -14,9 +14,11 @@ from scout.server.extensions import mail, store
 TEST_TOKEN = "test_token"
 
 
-def test_rerun(app, institute_obj, case_obj, monkeypatch):
+def test_rerun(app, institute_obj, case_obj, monkeypatch, mocker, mock_redirect):
     """test case rerun function"""
 
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app
     # GIVEN a valid user
 
@@ -40,7 +42,7 @@ def test_rerun(app, institute_obj, case_obj, monkeypatch):
                 "cases.rerun",
                 institute_id=institute_obj["internal_id"],
                 case_name=case_obj["display_name"],
-            )
+            ),
         )
         assert resp.status_code == 302
         updated_case = store.case_collection.find_one()
@@ -79,7 +81,12 @@ def test_parse_raw_gene_ids(app):
     assert hgnc_ids == {1234, 4321}
 
 
-def test_update_cancer_case_sample(app, user_obj, institute_obj, cancer_case_obj):
+def test_update_cancer_case_sample(
+    app, user_obj, institute_obj, cancer_case_obj, mocker, mock_redirect
+):
+
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app
     # GIVEN a valid user and institute
 
@@ -146,7 +153,7 @@ def test_institutes(app):
         assert resp.status_code == 200
 
 
-def test_case_outdated_panel(app, institute_obj, case_obj, dummy_case):
+def test_case_outdated_panel(app, institute_obj, case_obj):
     """Test case displaying an outdated panel warning badge"""
 
     # GIVEN an adapter with a case with a gene panel of version 1
@@ -204,7 +211,9 @@ def test_case_sma(app, case_obj, institute_obj):
         assert resp.status_code == 200
 
 
-def test_update_individual(app, user_obj, institute_obj, case_obj):
+def test_update_individual(app, user_obj, institute_obj, case_obj, mocker, mock_redirect):
+
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
     # GIVEN an initialized app
     # GIVEN a valid user and institute
 
@@ -252,7 +261,10 @@ def test_update_individual(app, user_obj, institute_obj, case_obj):
         )
 
 
-def test_case_synopsis(app, institute_obj, case_obj):
+def test_case_synopsis(app, institute_obj, case_obj, mocker, mock_redirect):
+
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app
     # GIVEN a valid user and institute
 
@@ -270,15 +282,17 @@ def test_case_synopsis(app, institute_obj, case_obj):
                 institute_id=institute_obj["internal_id"],
                 case_name=case_obj["display_name"],
                 data=req_data,
-            )
+            ),
         )
         # then it should return a redirected page
         assert resp.status_code == 302
 
 
-def test_update_case_comment(app, institute_obj, case_obj, user_obj):
+def test_update_case_comment(app, institute_obj, case_obj, user_obj, mocker, mock_redirect):
     """Test the functionality that allows updating of case-specific comments"""
 
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app
     with app.test_client() as client:
         # GIVEN that the user could be logged in
@@ -304,6 +318,7 @@ def test_update_case_comment(app, institute_obj, case_obj, user_obj):
             "updatedContent": "an updated comment",
             "edit": "",
         }
+
         resp = client.post(
             url_for(
                 "cases.events",
@@ -334,7 +349,6 @@ def test_add_case_group(app, case_obj, institute_obj):
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
 
-        # Given a page referrer (request to add case group starts from case page)
         referer = url_for(
             "cases.case",
             institute_id=institute_obj["internal_id"],
@@ -357,6 +371,7 @@ def test_add_case_group(app, case_obj, institute_obj):
 
 def test_remove_case_group(app, case_obj, institute_obj):
     """Test removing a case group."""
+
     ### GIVEN an initialized app
     group_id = ObjectId("101010101010101010101010")
     result = store.case_collection.find_one_and_update(
@@ -368,7 +383,6 @@ def test_remove_case_group(app, case_obj, institute_obj):
         # GIVEN that the user could be logged in
         resp = client.get(url_for("auto_login"))
 
-        # Given a page referrer (request to remove case group starts from case page)
         referer = url_for(
             "cases.case",
             institute_id=institute_obj["internal_id"],
@@ -449,9 +463,11 @@ def test_case_report(app, institute_obj, case_obj):
         assert resp.status_code == 200
 
 
-def test_case_diagnosis(app, institute_obj, case_obj):
+def test_case_diagnosis(app, institute_obj, case_obj, mocker, mock_redirect):
     # Test the web page containing the general case report
 
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app and a valid user and institute
     with app.test_client() as client:
         # GIVEN that the user could be logged in
@@ -540,141 +556,10 @@ def test_mt_report(app, institute_obj, case_obj):
         assert resp.mimetype == "application/zip"
 
 
-def test_matchmaker_add(app, institute_obj, case_obj):
-    # GIVEN an initialized app
-    # GIVEN a valid user and institute
+def test_status(app, institute_obj, case_obj, user_obj, mocker, mock_redirect):
 
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
 
-        # WHEN accessing the case page
-        resp = client.post(
-            url_for(
-                "cases.matchmaker_add",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-            )
-        )
-        # page redirects in the views anyway, so it will return a 302 code
-        assert resp.status_code == 302
-
-
-def test_matchmaker_matches(app, institute_obj, case_obj, mme_submission, user_obj, monkeypatch):
-
-    # Given a case object with a MME submission
-    case_obj["mme_submission"] = mme_submission
-    store.update_case(case_obj)
-
-    res = store.case_collection.find({"mme_submission": {"$exists": True}})
-    assert res
-
-    # Monkeypatch response with MME matches
-    def mock_matches(*args, **kwargs):
-        return {"institute": institute_obj, "case": case_obj, "matches": {}}
-
-    monkeypatch.setattr(controllers, "mme_matches", mock_matches)
-
-    # GIVEN an initialized app
-    # GIVEN a valid institute and a user with mme_submitter role
-    store.user_collection.update_one(
-        {"_id": user_obj["_id"]}, {"$set": {"roles": ["mme_submitter"]}}
-    )
-
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        # Given mock MME connection parameters
-        current_app.config["MME_URL"] = "http://fakey_mme_url:fakey_port"
-        current_app.config["MME_TOKEN"] = TEST_TOKEN
-
-        # WHEN accessing the case page
-        resp = client.get(
-            url_for(
-                "cases.matchmaker_matches",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-            )
-        )
-
-        # Then a successful response should be generated
-        assert resp.status_code == 200
-
-
-def test_matchmaker_match(app, institute_obj, case_obj, mme_submission, user_obj, monkeypatch):
-
-    # Given a case object with a MME submission
-    case_obj["mme_submission"] = mme_submission
-    store.update_case(case_obj)
-
-    res = store.case_collection.find({"mme_submission": {"$exists": True}})
-    assert sum(1 for i in res) == 1
-
-    # Monkeypatch response with MME match
-    def mock_match(*args, **kwargs):
-        return [{"status_code": 200}]
-
-    monkeypatch.setattr(controllers, "mme_match", mock_match)
-
-    # GIVEN an initialized app
-    # GIVEN a valid institute and a user with mme_submitter role
-    store.user_collection.update_one(
-        {"_id": user_obj["_id"]}, {"$set": {"roles": ["mme_submitter"]}}
-    )
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        # Given mock MME connection parameters
-        current_app.config["MME_URL"] = "http://fakey_mme_url:fakey_port"
-        current_app.config["MME_TOKEN"] = TEST_TOKEN
-
-        # WHEN sending a POST request to match a patient
-        resp = client.post(
-            url_for(
-                "cases.matchmaker_match",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-                target="mock_node_id",
-            )
-        )
-        # page redirects in the views anyway, so it will return a 302 code
-        assert resp.status_code == 302
-
-
-def test_matchmaker_delete(app, institute_obj, case_obj, mme_submission):
-    # GIVEN an initialized app
-    # GIVEN a valid user and institute
-
-    with app.test_client() as client:
-        # GIVEN that the user could be logged in
-        resp = client.get(url_for("auto_login"))
-        assert resp.status_code == 200
-
-        # add MME submission to case object
-        store.case_collection.find_one_and_update(
-            {"_id": case_obj["_id"]}, {"$set": {"mme_submission": mme_submission}}
-        )
-        res = store.case_collection.find({"mme_submission": {"$exists": True}})
-        assert sum(1 for i in res) == 1
-
-        # WHEN accessing the case page
-        resp = client.post(
-            url_for(
-                "cases.matchmaker_delete",
-                institute_id=institute_obj["internal_id"],
-                case_name=case_obj["display_name"],
-            )
-        )
-        # page redirects in the views anyway, so it will return a 302 code
-        assert resp.status_code == 302
-
-
-def test_status(app, institute_obj, case_obj, user_obj):
     # GIVEN an initialized app
     # GIVEN a valid user and institute
 
@@ -800,22 +685,22 @@ def test_omimterms(app, test_omim_term):
         assert resp.mimetype == "application/json"
 
 
-def _test_beacon_submit(client, case_obj, vcf_files):
+def _test_beacon_submit(client, institute_obj, case_obj, vcf_files, mocker, mock_redirect):
     """Test beacon connection: given client, produce response"""
+
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     form_data = {
         "case": case_obj["_id"],
         "samples": "affected",
         "vcf_files": vcf_files,
     }
     # WHEN case page is loaded
-    resp = client.post(
-        url_for("cases.beacon_submit"),
-        data=form_data,
-    )
+    resp = client.post(url_for("cases.beacon_submit"), data=form_data)
     return resp
 
 
-def test_beacon_submit_wrong_config(app, case_obj):
+def test_beacon_submit_wrong_config(app, institute_obj, case_obj, mocker, mock_redirect):
     """Test saving variants to a Beacon server when Beacon connection parameters are not set"""
 
     # GIVEN an initialized app
@@ -826,7 +711,9 @@ def test_beacon_submit_wrong_config(app, case_obj):
 
         vcf_files = ["vcf_snv_research", "vcf_snv"]
         # WHEN case page is loaded without beacon config settings
-        resp = _test_beacon_submit(client, case_obj, vcf_files)
+        resp = _test_beacon_submit(
+            client, institute_obj, case_obj, vcf_files, mocker, mock_redirect
+        )
 
         # THEN it should redirect to case page
         assert resp.status_code == 302
@@ -835,7 +722,9 @@ def test_beacon_submit_wrong_config(app, case_obj):
         assert "beacon" not in updated_case
 
 
-def test_beacon_submit(app, case_obj, monkeypatch, mocked_beacon):
+def test_beacon_submit(
+    app, institute_obj, case_obj, monkeypatch, mocked_beacon, mocker, mock_redirect
+):
     """Test submitting variants to a Beacon server"""
 
     # GIVEN a mocked Beacon server
@@ -855,7 +744,14 @@ def test_beacon_submit(app, case_obj, monkeypatch, mocked_beacon):
 
         vcf_files = ["vcf_snv_research", "vcf_snv"]
         # WHEN case page is loaded
-        resp = _test_beacon_submit(client, case_obj, vcf_files)
+        resp = _test_beacon_submit(
+            client,
+            institute_obj,
+            case_obj,
+            vcf_files,
+            mocker,
+            mock_redirect,
+        )
 
         # THEN it should redirect to case page
         assert resp.status_code == 302
@@ -866,9 +762,13 @@ def test_beacon_submit(app, case_obj, monkeypatch, mocked_beacon):
         assert updated_case["beacon"]["vcf_files"] == vcf_files
 
 
-def test_beacon_remove(app, case_obj, monkeypatch, mocked_beacon):
+def test_beacon_remove(
+    app, institute_obj, case_obj, monkeypatch, mocked_beacon, mocker, mock_redirect
+):
     """Test removing variants submitted to Beacon for test case"""
 
+    mocker.patch("scout.server.blueprints.cases.views.redirect", return_value=mock_redirect)
+
     # GIVEN a mocked Beacon server
     def mock_response(*args, **kwargs):
         return mocked_beacon
