@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import datetime
 
+import pytest
 from flask import url_for
 from flask_login import current_user
 
@@ -38,9 +39,11 @@ def test_advanced_phenotypes_POST(app, user_obj, institute_obj):
         assert form_data["model_name"] in str(resp.data)
 
 
-def test_remove_phenomodel(app, user_obj, institute_obj):
+def test_remove_phenomodel(app, user_obj, institute_obj, mocker, mock_redirect):
     """Testing the endpoint to remove an existing phenotype model for an institute"""
 
+    mocker.patch("scout.server.blueprints.institutes.views.redirect", return_value=mock_redirect)
+
     # GIVEN an institute with a phenotype model
     store.create_phenomodel(institute_obj["internal_id"], "Test model", "Model description")
     model_obj = store.phenomodel_collection.find_one()
@@ -86,9 +89,11 @@ def test_phenomodel_GET(app, user_obj, institute_obj):
         assert "Test model" in str(resp.data)
 
 
-def test_phenomodel_lock(app, user_obj, institute_obj):
+def test_phenomodel_lock(app, user_obj, institute_obj, mocker, mock_redirect):
     """Test the endpoint to lock a phenomodel and make it editable only by admins"""
 
+    mocker.patch("scout.server.blueprints.institutes.views.redirect", return_value=mock_redirect)
+
     # GIVEN an institute with a phenotype model
     store.create_phenomodel(institute_obj["internal_id"], "Test model", "Model description")
     model = store.phenomodel_collection.find_one()
@@ -114,9 +119,11 @@ def test_phenomodel_lock(app, user_obj, institute_obj):
         assert locked_model["admins"] == [current_user.email] + admins
 
 
-def test_phenomodel_unlock(app, user_obj, institute_obj):
+def test_phenomodel_unlock(app, user_obj, institute_obj, mocker, mock_redirect):
     """Test the endpoint to unlock a phenomodel and make it editable only by all users"""
 
+    mocker.patch("scout.server.blueprints.institutes.views.redirect", return_value=mock_redirect)
+
     # GIVEN an institute with phenotype model
     store.create_phenomodel(institute_obj["internal_id"], "Test model", "Model description")
     model = store.phenomodel_collection.find_one()
@@ -724,9 +731,11 @@ def test_gene_variants_filter(app, institute_obj, case_obj):
         assert "POT1" in str(resp.data)
 
 
-def test_gene_variants_no_valid_gene(app, institute_obj, case_obj):
+def test_gene_variants_no_valid_gene(app, institute_obj, case_obj, mocker, mock_redirect):
     """Test the gene_variant endpoint with a gene symbol not in database"""
 
+    mocker.patch("scout.server.blueprints.institutes.views.redirect", return_value=mock_redirect)
+
     # GIVEN an initialized app
     # GIVEN a valid user and institute
     with app.test_client() as client:
@@ -769,6 +778,28 @@ def test_institute_users(app, institute_obj, user_obj):
         assert user_obj["name"] in str(resp.data)
 
 
+def test_filters(app, institute_obj, user_obj, case_obj, filter_obj):
+    """Test the link to all institute users"""
+    # GIVEN an initialized app
+    # GIVEN a valid user and institute
+    with app.test_client() as client:
+        # GIVEN that the user could be logged in
+        resp = client.get(url_for("auto_login"))
+
+        category = "snv"
+        filter_id = store.stash_filter(filter_obj, institute_obj, case_obj, user_obj, category)
+        store.lock_filter(filter_id, user_obj.get("email"))
+
+        # WHEN accessing the cases page
+        resp = client.get(url_for("overview.filters", institute_id=institute_obj["internal_id"]))
+
+        # THEN it should return a page
+        assert resp.status_code == 200
+
+        # Containing the test user's name
+        assert user_obj["name"] in str(resp.data)
+
+
 def test_clinvar_submissions(app, institute_obj, clinvar_variant, clinvar_casedata):
     """Test the web page containing the clinvar submissions for an institute"""
 
